/*******************************************************************************
* File Name: ETW.c  
* Version 1.70
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <ETW.H>

#if !defined(ETW__REMOVED) /* Check for removal by optimization */

/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START ETW_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE      16
#endif /* CYINT_IRQ_BASE */
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif /* CYINT_VECT_TABLE */

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);


/*******************************************************************************
* Function Name: ETW_Start
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ETW_Start(void)
{
    /* For all we know the interrupt is active. */
    ETW_Disable();

    /* Set the ISR to point to the ETW Interrupt. */
    ETW_SetVector(&ETW_Interrupt);

    /* Set the priority. */
    ETW_SetPriority((uint8)ETW_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ETW_Enable();
}


/*******************************************************************************
* Function Name: ETW_StartEx
********************************************************************************
*
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void ETW_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    ETW_Disable();

    /* Set the ISR to point to the ETW Interrupt. */
    ETW_SetVector(address);

    /* Set the priority. */
    ETW_SetPriority((uint8)ETW_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ETW_Enable();
}


/*******************************************************************************
* Function Name: ETW_Stop
********************************************************************************
*
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
void ETW_Stop(void)
{
    /* Disable this interrupt. */
    ETW_Disable();

    /* Set the ISR to point to the passive one. */
    ETW_SetVector(&IntDefaultHandler);
}


/*******************************************************************************
* Function Name: ETW_Interrupt
********************************************************************************
*
* Summary:
*   The default Interrupt Service Routine for ETW.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
* Parameters:  
*
* Return:
*   None
*
*******************************************************************************/
CY_ISR(ETW_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START ETW_Interrupt` */

    /* `#END` */
}


/*******************************************************************************
* Function Name: ETW_SetVector
********************************************************************************
*
* Summary:
*   Change the ISR vector for the Interrupt. Note calling ETW_Start
*   will override any effect this method would have had. To set the vector 
*   before the component has been started use ETW_StartEx instead.
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
* Return:
*   None
*
*******************************************************************************/
void ETW_SetVector(cyisraddress address)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + (uint32)ETW__INTC_NUMBER] = address;
}


/*******************************************************************************
* Function Name: ETW_GetVector
********************************************************************************
*
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*******************************************************************************/
cyisraddress ETW_GetVector(void)
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + (uint32)ETW__INTC_NUMBER];
}


/*******************************************************************************
* Function Name: ETW_SetPriority
********************************************************************************
*
* Summary:
*   Sets the Priority of the Interrupt. Note calling ETW_Start
*   or ETW_StartEx will override any effect this method 
*   would have had. This method should only be called after 
*   ETW_Start or ETW_StartEx has been called. To set 
*   the initial priority for the component use the cydwr file in the tool.
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
* Return:
*   None
*
*******************************************************************************/
void ETW_SetPriority(uint8 priority)
{
    *ETW_INTC_PRIOR = priority << 5;
}


/*******************************************************************************
* Function Name: ETW_GetPriority
********************************************************************************
*
* Summary:
*   Gets the Priority of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*******************************************************************************/
uint8 ETW_GetPriority(void)
{
    uint8 priority;


    priority = *ETW_INTC_PRIOR >> 5;

    return priority;
}


/*******************************************************************************
* Function Name: ETW_Enable
********************************************************************************
*
* Summary:
*   Enables the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ETW_Enable(void)
{
    /* Enable the general interrupt. */
    *ETW_INTC_SET_EN = ETW__INTC_MASK;
}


/*******************************************************************************
* Function Name: ETW_GetState
********************************************************************************
*
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   1 if enabled, 0 if disabled.
*
*******************************************************************************/
uint8 ETW_GetState(void)
{
    /* Get the state of the general interrupt. */
    return ((*ETW_INTC_SET_EN & (uint32)ETW__INTC_MASK) != 0u) ? 1u:0u;
}


/*******************************************************************************
* Function Name: ETW_Disable
********************************************************************************
*
* Summary:
*   Disables the Interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ETW_Disable(void)
{
    /* Disable the general interrupt. */
    *ETW_INTC_CLR_EN = ETW__INTC_MASK;
}


/*******************************************************************************
* Function Name: ETW_SetPending
********************************************************************************
*
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ETW_SetPending(void)
{
    *ETW_INTC_SET_PD = ETW__INTC_MASK;
}


/*******************************************************************************
* Function Name: ETW_ClearPending
********************************************************************************
*
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   None
*
* Return:
*   None
*
*******************************************************************************/
void ETW_ClearPending(void)
{
    *ETW_INTC_CLR_PD = ETW__INTC_MASK;
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
