/*******************************************************************************
* File Name: RES.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "RES.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 RES__PORT == 15 && ((RES__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: RES_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void RES_Write(uint8 value) 
{
    uint8 staticBits = (RES_DR & (uint8)(~RES_MASK));
    RES_DR = staticBits | ((uint8)(value << RES_SHIFT) & RES_MASK);
}


/*******************************************************************************
* Function Name: RES_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void RES_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(RES_0, mode);
}


/*******************************************************************************
* Function Name: RES_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro RES_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 RES_Read(void) 
{
    return (RES_PS & RES_MASK) >> RES_SHIFT;
}


/*******************************************************************************
* Function Name: RES_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 RES_ReadDataReg(void) 
{
    return (RES_DR & RES_MASK) >> RES_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(RES_INTSTAT) 

    /*******************************************************************************
    * Function Name: RES_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 RES_ClearInterrupt(void) 
    {
        return (RES_INTSTAT & RES_MASK) >> RES_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
