/*
 * Copyright (c) 2013. All rights reserved. 
 * 
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED 
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
 * SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT 
 * OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY 
 * OF SUCH DAMAGE.
 *
 * Author: Lars Randers <lranders@mail.dk>
 *
 */
#include <device.h>
#include <stdio.h>
#include <enc28j60.h>
#include <lwip/init.h>
#include <lwip/netif.h>
#include <lwip/dhcp.h>
#include <lwip/tcp_impl.h>
#include <netif/etharp.h>
#include <httpserver_raw/httpd.h>
#include <crc16.h>
#include <eeprom.h>
#include <lwip/raw.h>//////////////////

#include <MyISRs.h>

uint8 Table[1024]={0};

//volatile unsigned char g_ucFlags = 0;
volatile unsigned long g_ulTickCounter = 0;
volatile unsigned long g_ulIntCounter = 0;

//Timewheel is set at 20Hz, thus producing a tick every 50ms
#define TICK_MS 50

const epmLayout_t epmSaneValues = {
	.macAddress = {0x00,0x0d,0x65,0x2a,0x84,0x80},
	.ipAddress = {192,168,0,220},
	.netMask = {255,255,255,0},
	.gateWay = {192,168,0,1},
//	.u.bits.useDhcp = 1
     .u.bits.useDhcp = 0
};

#define HB_RESET 186000
uint32_t hb_counter = HB_RESET;
err_t Test;


void heartbeat(void)
{
	if(--hb_counter == 0) {
		HB_Write(~HB_Read());
		hb_counter = HB_RESET;
	}
}

//Convenience macro for readability
#define EPM(member) ((epmLayout_t *)epm)->member

//############################################     recv_callback     ##############################################
static err_t recv_callback(void *arg, struct tcp_pcb *pcb, struct pbuf *p, err_t err)
{
    uint16 i;
    printf("------------>recv_callback\n");
    /* indicate that the packet has been received */
    tcp_recved(pcb, p->len);    
    
    /* echo back the payload */
 for (i=0;i<3;i++ )   
    {tcp_write(pcb, Table, 1024, 1);  //+++++++++++++++++++++++++++++++  
    }   
    return ERR_OK;
}

//############################################     accept_callback     ##############################################
 static err_t accept_callback(void *arg, struct tcp_pcb *pcb, err_t err)
{
    /* Set up the function http_recv() to be called when data  arrives. */
    tcp_recv(pcb, recv_callback); 
    return ERR_OK;
}
///..........................................................................................
static struct tcp_pcb *pcb;
#define LWIP_PLATFORM_DIAG(msg) do {printf msg;} while(0)
//############################################   tcp_init_func   ##############################################
void tcp_init_func(void)
{
    /* Create a new TCP PCB. */
    pcb = tcp_new();    //protocol control block
    /* Bind the PCB to TCP port 10000. */
    err_t res;
    //res = tcp_bind(pcb, NULL, 10000);
    res = tcp_bind(pcb, IP_ADDR_ANY, 10000);// адрес и порт
    printf("--->tcp_bind_res=%d\n",res);
    tcp_arg(pcb, NULL);
    /* Change TCP state to LISTEN. */
     pcb =tcp_listen(pcb); 
     printf("--->tcp_listen_res=%d\n",res);
    /* Set up http_accet() function to be called   when a new connection arrives. */
    tcp_accept(pcb, accept_callback);
    //tcp_recv(pcb, recv_callback);//&&&&&&&&&&&&&&&&&&&&&&&&&&&&????????????????????
}
//#############################################################################################################
uint16 i=0;
void main()
{
 for (i=0;i<1024;i++ )  Table[i] =i;// fill table for send

	struct netif netif;
	ip_addr_t ipaddr, netmask, gw;

	URT_Start();
	ETH_Start(); //ethernet SPI link
	ETW_Start(); //ethernet time wheel


	enc_init(epmSaneValues.macAddress);  //enc28j60  541

//	if(epmSaneValues.u.bits.useDhcp) {
//		g_ucFlags |= (1<<FLAG_USE_DHCP);
//	  }

	LCD_Start(); 	LCD_Position(0,0);	LCD_PrintString("Hello all");
	
    
    ETW_StartEx(ETW_ISR);  
    CyGlobalIntEnable;

	lwip_init();    // init.c  290

	if(1) {
   // if((g_ucFlags & (1<<FLAG_USE_DHCP)) == 0) {
        IP4_ADDR(&ipaddr,epmSaneValues.ipAddress[0], epmSaneValues.ipAddress[1], epmSaneValues.ipAddress[2], epmSaneValues.ipAddress[3]);
        IP4_ADDR(&netmask, epmSaneValues.netMask[0],  epmSaneValues.netMask[1],  epmSaneValues.netMask[2],  epmSaneValues.netMask[3]);
           IP4_ADDR(&gw,     epmSaneValues.gateWay[0], epmSaneValues.gateWay[1],  epmSaneValues.gateWay[2],  epmSaneValues.gateWay[3]);
	} else {
		IP4_ADDR(&ipaddr,  0, 0, 0, 0);
		IP4_ADDR(&netmask, 0, 0, 0, 0);
		IP4_ADDR(&gw,      0, 0, 0, 0);
	}
//------------------------------------------------------------------------------------------------------------------------------------------------
	netif_add(&netif, &ipaddr, &netmask, &gw, NULL, enc28j60_init, ethernet_input);
	netif_set_default(&netif);

	if(0) {
    //if(g_ucFlags & (1<<FLAG_USE_DHCP)) {
		dhcp_start(&netif);
	} else {
		netif_set_up(&netif);  
        	}

	unsigned long lastArpTime = 0, lastTcpTime = 0, lastDhcpCoarseTime = 0, lastDhcpFineTime = 0;
  
  //**************************************************************************************************************************************  
    tcp_init_func();    // Create a new TCP; PCB addr & port

	while(1)
	{
		if((g_ulTickCounter - lastArpTime) >= (ARP_TMR_INTERVAL / TICK_MS)) {
			etharp_tmr();
			lastArpTime = g_ulTickCounter;
		}
        
		if((g_ulTickCounter - lastTcpTime) >= (TCP_TMR_INTERVAL / TICK_MS)) {
			tcp_tmr();
			lastTcpTime = g_ulTickCounter;
		}

        if(1) {
			enc_action(&netif);//   It should be called when the ENC28J60 has signaled an interrupt

		      }
		heartbeat();
   
	}
}

/* [] END OF FILE */
